betty.test_utils.privacy - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.test_utils.privacy

    """
    Test utilities for :py:mod:`betty.privacy`.
    """

    from betty.privacy import HasPrivacy

    class DummyHasPrivacy(HasPrivacy):
        """
        A dummy :py:class:`betty.privacy.HasPrivacy` implementation.
        """

        pass